==> haskell-hspec-smallcheck-0.5.3-87-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-smallcheck
version:              0.5.3
visibility:           public
id:                   hspec-smallcheck-0.5.3-JW33kYQwQ74IglDsyECKcn
key:                  hspec-smallcheck-0.5.3-JW33kYQwQ74IglDsyECKcn
license:              MIT
copyright:            (c) 2013-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
homepage:             http://hspec.github.io/
synopsis:             SmallCheck support for the Hspec testing framework
description:          SmallCheck support for the Hspec testing framework
category:             Testing
abi:                  08ad882605a0e7b8789136ce82ff8cf8
exposed:              True
exposed-modules:      Test.Hspec.SmallCheck
hidden-modules:
    Test.Hspec.SmallCheck.Compat Test.Hspec.SmallCheck.Types
    Paths_hspec_smallcheck

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-smallcheck-0.5.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-smallcheck-0.5.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-smallcheck-0.5.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-smallcheck
hs-libraries:         HShspec-smallcheck-0.5.3-JW33kYQwQ74IglDsyECKcn
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA base-4.17.2.1
    call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo
    hspec-core-2.10.10-38lz15eDkOH7kHmMvTOpEK
    smallcheck-1.2.1.1-6geuxqjOW2e8AdoLtxZPJT

haddock-interfaces:
    /usr/share/doc/haskell-hspec-smallcheck/html/hspec-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-hspec-smallcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-smallcheck-0.5.3-88-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-smallcheck
version:              0.5.3
visibility:           public
id:                   hspec-smallcheck-0.5.3-Atr2kLgCz6h54KHje8dYHO
key:                  hspec-smallcheck-0.5.3-Atr2kLgCz6h54KHje8dYHO
license:              MIT
copyright:            (c) 2013-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
homepage:             http://hspec.github.io/
synopsis:             SmallCheck support for the Hspec testing framework
description:          SmallCheck support for the Hspec testing framework
category:             Testing
abi:                  3c5fe2050b8d26481ca0b46b05f99e99
exposed:              True
exposed-modules:      Test.Hspec.SmallCheck
hidden-modules:
    Test.Hspec.SmallCheck.Compat Test.Hspec.SmallCheck.Types
    Paths_hspec_smallcheck

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-smallcheck-0.5.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-smallcheck-0.5.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-smallcheck-0.5.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-smallcheck
hs-libraries:         HShspec-smallcheck-0.5.3-Atr2kLgCz6h54KHje8dYHO
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA base-4.17.2.1
    call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo
    hspec-core-2.10.10-ABRhZ7CPsjT43HeuDHC86X
    smallcheck-1.2.1.1-7jML5aKfCe99hIUUnoEi6p

haddock-interfaces:
    /usr/share/doc/haskell-hspec-smallcheck/html/hspec-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-hspec-smallcheck/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
